@@ -1,6 +1,6 @@
 #! /usr/bin/perl
 
-# $Id: lamdaemon.pl,v 1.51 2009/12/12 17:24:41 gruberroland Exp $
+# $Id: lamdaemon.pl,v 1.55 2010/05/14 12:57:00 gruberroland Exp $
 #
 #  This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
 #  Copyright (C) 2003 - 2006  Tilo Lutz
@@ -105,34 +105,30 @@ if ($< != 0 ) {
 
 # Drop root privileges
 ($<, $>) = ($>, $<);
-# loop for every transmitted user
-while (1) {
-	my $input = <STDIN>;
-	chop($input);
-	$return = "";
-	@vals = split ($SPLIT_DELIMITER, $input);
-	# Get user information
-	if (($vals[3] eq 'user') || ($vals[1] eq 'home')) { @user = getpwnam($vals[0]); }
-	else { @user = getgrnam($vals[0]); }
-	if ($vals[1] eq '') {
-		# empty line, nothing to do
-	}
-	elsif (($vals[1] eq 'test')) {
-		# run tests
-		runTest();
-	}
-	elsif ($vals[1] eq 'home') {
-		manageHomedirs();
-	}
-	elsif ($vals[1] eq 'quota') {
-		manageQuotas();
-	}
-	else {
-		$return = "ERROR,Lamdaemon ($hostname),Unknown command $vals[1].";
-		logMessage(LOG_ERR, "Unknown command $vals[1].");
-	}
-	print "$return\n";
+my $input = $ARGV[0];
+$return = "";
+@vals = split ($SPLIT_DELIMITER, $input);
+# Get user information
+if (($vals[3] eq 'user') || ($vals[1] eq 'home')) { @user = getpwnam($vals[0]); }
+else { @user = getgrnam($vals[0]); }
+if ($vals[1] eq '') {
+	# empty line, nothing to do
 }
+elsif (($vals[1] eq 'test')) {
+	# run tests
+	runTest();
+}
+elsif ($vals[1] eq 'home') {
+	manageHomedirs();
+}
+elsif ($vals[1] eq 'quota') {
+	manageQuotas();
+}
+else {
+	$return = "ERROR,Lamdaemon ($hostname),Unknown command $vals[1].";
+	logMessage(LOG_ERR, "Unknown command $vals[1].");
+}
+print "$return\n";
 
 #
 # Runs tests to check the environment
@@ -140,12 +136,34 @@ while (1) {
 sub runTest {
 	# basic test
 	if ($vals[2] eq 'basic') {
-		$return = "Ok";
+		$return = "INFO,Basic test ok";
 	}
 	# quota test
 	elsif ($vals[2] eq 'quota') {
 		require Quota;
-		$return = "Ok";
+		$return = "INFO,Quota test ok";
+	}
+	# NSS LDAP
+	elsif ($vals[2] eq 'nss') {
+		$userName = $vals[3];
+		# check if the user exists in /etc/passwd
+		system("grep", "-q", "^" . $userName . ":", "/etc/passwd");
+		if ( $? == 0 ) {
+			$error = "User $userName is a local user (/etc/passwd) but should be LDAP only.";
+			$return = "ERROR,$error";
+			logMessage(LOG_ERR, $error);
+		}
+		else {
+			# check if home directory is readable
+			@user = getpwnam($userName);
+			if ($user[7] eq '') {
+				$return = "ERROR,Unable to determine home directory of user $userName. Please check that NSS LDAP is correctly configured.";
+				logMessage(LOG_ERR, "Unable to determine home directory of user $userName. Please check that NSS LDAP is correctly configured.");
+			}
+			else {
+				$return = "INFO,NSS test ok";
+			}
+		}
 	}
 }
 
@@ -172,8 +190,8 @@ sub manageHomedirs {
 sub createHomedir {
 	my $homedir = $user[7];
 	if ($homedir eq '') {
-		$return = "ERROR,Lamdaemon ($hostname),Home directory path is empty.";
-		logMessage(LOG_ERR, "Home directory path is empty.");
+		$return = "ERROR,Lamdaemon ($hostname),Unable to determine home directory path. Please check if NSS LDAP is correctly configured.";
+		logMessage(LOG_ERR, "Unable to determine home directory path. Please check if NSS LDAP is correctly configured.");
 		return;
 	}
 	my $path = $homedir;
@@ -322,12 +340,12 @@ sub getQuotas {
 						logMessage(LOG_ERR, "Unable to read quota for $user[0].");
 					}
 				else {
-					$return = "$quota_usr[$i][1],$temp[0],$temp[1],$temp[2],$temp[3],$temp[4],$temp[5],$temp[6],$temp[7]:$return";
+					$return = "QUOTA_ENTRY $quota_usr[$i][1],$temp[0],$temp[1],$temp[2],$temp[3],$temp[4],$temp[5],$temp[6],$temp[7]:$return";
 					}
 				}
-			else { $return = "$quota_usr[$i][1],0,0,0,0,0,0,0,0:$return"; }
+			else { $return = "QUOTA_ENTRY $quota_usr[$i][1],0,0,0,0,0,0,0,0:$return"; }
 			}
-		else { $return = "$quota_usr[$i][1],0,0,0,0,0,0,0,0:$return"; }
+		else { $return = "QUOTA_ENTRY $quota_usr[$i][1],0,0,0,0,0,0,0,0:$return"; }
 		$i++;
 		}
 	($<, $>) = ($>, $<); # Give up root previleges
