@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: conflogin.php,v 1.45 2009/10/27 18:46:33 gruberroland Exp $
+$Id: conflogin.php,v 1.47 2010/02/06 11:50:26 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2009  Roland Gruber
+  Copyright (C) 2003 - 2010  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -37,9 +37,10 @@ include_once('../../lib/status.inc');
 
 // start session
 if (strtolower(session_module_name()) == 'files') {
-	session_save_path("../../sess");
+	session_save_path(dirname(__FILE__) . '/../../sess');
 }
-@session_start();
+session_start();
+session_regenerate_id(true);
 
 setlanguage();
 
@@ -66,7 +67,13 @@ echo $_SESSION['header'];
 	</head>
 	<body>
 		<?php
-			echo "<script type=\"text/javascript\" src=\"../wz_tooltip.js\"></script>\n";
+			// include all JavaScript files
+			$jsDirName = dirname(__FILE__) . '/../lib';
+			$jsDir = dir($jsDirName);
+			while ($jsEntry = $jsDir->read()) {
+				if (substr($jsEntry, strlen($jsEntry) - 3, 3) != '.js') continue;
+				echo "<script type=\"text/javascript\" src=\"../lib/" . $jsEntry . "\"></script>\n";
+			}
 			// set focus on password field
 			echo "<script type=\"text/javascript\" language=\"javascript\">\n";
 			echo "<!--\n";
