@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: confmain.php,v 1.112 2009/11/13 20:12:34 gruberroland Exp $
+$Id: confmain.php,v 1.116 2010/02/20 17:26:10 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2009  Roland Gruber
+  Copyright (C) 2003 - 2010  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -53,7 +53,7 @@ if (isset($_POST['passwd'])) $passwd = $_POST['passwd'];
 if (!isset($passwd) && !isset($_SESSION['conf_isAuthenticated'])) {
 	$_SESSION['conf_message'] = _("No password was entered!");
 	/** go back to login if password is empty */
-	require('conflogin.php');
+	metaRefresh('conflogin.php');
 	exit;
 }
 
@@ -71,7 +71,7 @@ if ((!isset($_SESSION['conf_isAuthenticated']) || !($_SESSION['conf_isAuthentica
 	}
 	$_SESSION['conf_message'] = _("The password is invalid! Please try again.");
 	/** go back to login if password is invalid */
-	require('conflogin.php');
+	metaRefresh('conflogin.php');
 	exit;
 }
 $_SESSION['conf_isAuthenticated'] = $conf->getName();
@@ -124,8 +124,13 @@ echo ("<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/layout.css\
 echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"../../graphics/favicon.ico\">\n";
 echo ("</head>\n");
 echo ("<body onload=\"configLoginMethodChanged()\">\n");
-echo "<script type=\"text/javascript\" src=\"../wz_tooltip.js\"></script>\n";
-echo "<script type=\"text/javascript\" src=\"config.js\"></script>\n";
+// include all JavaScript files
+$jsDirName = dirname(__FILE__) . '/../lib';
+$jsDir = dir($jsDirName);
+while ($jsEntry = $jsDir->read()) {
+	if (substr($jsEntry, strlen($jsEntry) - 3, 3) != '.js') continue;
+	echo "<script type=\"text/javascript\" src=\"../lib/" . $jsEntry . "\"></script>\n";
+}
 echo ("<p align=\"center\"><a href=\"http://www.ldap-account-manager.org/\" target=\"new_window\">".
 	"<img src=\"../../graphics/banner.jpg\" border=1 alt=\"LDAP Account Manager\"></a></p>\n<hr>\n<p>&nbsp;</p>\n");
 
@@ -280,6 +285,28 @@ echo "<td>";
 printHelpLink(getHelp('', '214'), '214');
 echo "</td></tr>\n";
 
+// LDAP search limit
+$searchLimitOptions = array(
+array(0, '-'), array(100, 100), array(500, 500),
+array(1000, 1000), array(5000, 5000), array(10000, 10000),
+array(50000, 50000), array(100000, 100000)
+);
+echo ("<tr><td align=\"right\"><b>".
+	_("LDAP search limit") . ": </b></td>".
+	"<td><select tabindex=\"$tabindex\" name=\"searchLimit\">\n");
+for ($i = 0; $i < sizeof($searchLimitOptions); $i++) {
+	$selected = "";
+	if ($searchLimitOptions[$i][0] == $conf->get_searchLimit()) {
+		$selected = "selected";
+	}
+	echo "<option value=\"" . $searchLimitOptions[$i][0] . "\" $selected>" . $searchLimitOptions[$i][1] . "</option>";
+}
+echo ("</select></td>\n");
+$tabindex++;
+echo "<td>";
+printHelpLink(getHelp('', '222'), '222');
+echo "</td></tr>\n";
+
 // access level is only visible in Pro version
 if (isLAMProVersion()) {
 	// new line
@@ -363,8 +390,8 @@ echo ("</fieldset>\n");
 
 echo ("<br>\n");
 
-// script settings
-echo ("<fieldset><legend><img align=\"middle\" src=\"../../graphics/lamdaemon.png\" alt=\"lamdaemon.png\"> <b>" . _("Script settings") . "</b></legend><br>\n");
+// lamdaemon settings
+echo ("<fieldset><legend><img align=\"middle\" src=\"../../graphics/lamdaemon.png\" alt=\"lamdaemon.png\"> <b>" . _("Lamdaemon settings") . "</b></legend><br>\n");
 echo ("<table border=0>\n");
 
 echo ("<tr><td align=\"right\"><b>".
@@ -535,6 +562,7 @@ function checkInput() {
 	if (!$conf->set_cacheTimeout($_POST['cachetimeout'])) {
 		$errors[] = array("ERROR", _("Cache timeout is invalid!"));
 	}
+	$conf->set_searchLimit($_POST['searchLimit']);
 	if (isLAMProVersion()) {
 		$conf->setAccessLevel($_POST['accessLevel']);
 	}
