@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: confmodules.php,v 1.33 2009/11/13 20:12:34 gruberroland Exp $
+$Id: confmodules.php,v 1.36 2010/04/04 12:47:15 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2004 - 2009  Roland Gruber
+  Copyright (C) 2004 - 2010  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -101,7 +101,13 @@ for ($i = 0; $i < sizeof($types); $i++){
 	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/type_" . $types[$i] . ".css\">\n";
 }
 echo "</head><body>\n";
-echo "<script type=\"text/javascript\" src=\"../wz_tooltip.js\"></script>\n";
+// include all JavaScript files
+$jsDirName = dirname(__FILE__) . '/../lib';
+$jsDir = dir($jsDirName);
+while ($jsEntry = $jsDir->read()) {
+	if (substr($jsEntry, strlen($jsEntry) - 3, 3) != '.js') continue;
+	echo "<script type=\"text/javascript\" src=\"../lib/" . $jsEntry . "\"></script>\n";
+}
 
 echo ("<p align=\"center\"><a href=\"http://www.ldap-account-manager.org/\" target=\"new_window\">".
 	"<img src=\"../../graphics/banner.jpg\" border=1 alt=\"LDAP Account Manager\"></a></p><hr>\n<p>&nbsp;</p>\n");
@@ -230,6 +236,11 @@ function config_showAccountModules($scope, $title) {
 	else {
 		$selected = array();
 	}
+	$sortedAvailable = array();
+	for ($i = 0; $i < sizeof($available); $i++) {
+		$sortedAvailable[$available[$i]] = getModuleAlias($available[$i], $scope);
+	}
+	natcasesort($sortedAvailable);
 
 	// show account modules
 	$icon = '<img alt="' . $scope . '" src="../../graphics/' . $scope . '.png">&nbsp;';
@@ -246,12 +257,12 @@ function config_showAccountModules($scope, $title) {
 							if (in_array($selected[$i], $available)) {  // selected modules must be available
 								if (is_base_module($selected[$i], $scope)) {  // mark base modules
 									echo "<option value=\"" . $selected[$i] . "\">";
-									echo getModuleAlias($selected[$i], $scope) . "(" . $selected[$i] .  ")(*)";
+									echo getModuleAlias($selected[$i], $scope) . " (" . $selected[$i] .  ")(*)";
 									echo "</option>\n";
 								}
 								else {
 									echo "<option value=\"" . $selected[$i] . "\">";
-									echo getModuleAlias($selected[$i], $scope) . "(" . $selected[$i] .  ")";
+									echo getModuleAlias($selected[$i], $scope) . " (" . $selected[$i] .  ")";
 									echo "</option>\n";
 								}
 							}
@@ -272,16 +283,16 @@ function config_showAccountModules($scope, $title) {
 				echo "<fieldset class=\"" . $scope . "edit\">\n";
 					echo "<legend>" . _("Available modules") . "</legend><br>\n";
 					echo "<select class=\"" . $scope . "edit\" name=\"" . $scope . "_available[]\" size=5 multiple>\n";
-						for ($i = 0; $i < sizeof($available); $i++) {
-							if (! in_array($available[$i], $selected)) {  // display non-selected modules
-								if (is_base_module($available[$i], $scope)) {  // mark base modules
-									echo "<option value=\"" . $available[$i] . "\">";
-									echo getModuleAlias($available[$i], $scope) . "(" . $available[$i] .  ")(*)";
+						foreach ($sortedAvailable as $key => $value) {
+							if (! in_array($key, $selected)) {  // display non-selected modules
+								if (is_base_module($key, $scope)) {  // mark base modules
+									echo "<option value=\"" . $key . "\">";
+									echo $value . " (" . $key .  ")(*)";
 									echo "</option>\n";
 								}
 								else {
-									echo "<option value=\"" . $available[$i] . "\">";
-									echo getModuleAlias($available[$i], $scope) . "(" . $available[$i] .  ")";
+									echo "<option value=\"" . $key . "\">";
+									echo $value . " (" . $key .  ")";
 									echo "</option>\n";
 								}
 							}
