@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: conftypes.php,v 1.24 2009/11/13 20:12:34 gruberroland Exp $
+$Id: conftypes.php,v 1.26 2010/04/04 12:52:20 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2004 - 2009  Roland Gruber
+  Copyright (C) 2004 - 2010  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -104,8 +104,11 @@ $allTypes = getTypes();
 $activeTypes = $conf->get_ActiveTypes();
 $availableTypes = array();
 for ($i = 0; $i < sizeof($allTypes); $i++) {
-	if (!in_array($allTypes[$i], $activeTypes)) $availableTypes[] = $allTypes[$i];
+	if (!in_array($allTypes[$i], $activeTypes)) {
+		$availableTypes[$allTypes[$i]] = getTypeAlias($allTypes[$i]);
+	}
 }
+natcasesort($availableTypes);
 
 echo $_SESSION['header'];
 
@@ -116,7 +119,13 @@ for ($i = 0; $i < sizeof($allTypes); $i++){
 	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/type_" . $allTypes[$i] . ".css\">\n";
 }
 echo "</head><body>\n";
-echo "<script type=\"text/javascript\" src=\"../wz_tooltip.js\"></script>\n";
+// include all JavaScript files
+$jsDirName = dirname(__FILE__) . '/../lib';
+$jsDir = dir($jsDirName);
+while ($jsEntry = $jsDir->read()) {
+	if (substr($jsEntry, strlen($jsEntry) - 3, 3) != '.js') continue;
+	echo "<script type=\"text/javascript\" src=\"../lib/" . $jsEntry . "\"></script>\n";
+}
 
 echo ("<p align=\"center\"><a href=\"http://www.ldap-account-manager.org/\" target=\"new_window\">".
 	"<img src=\"../../graphics/banner.jpg\" border=1 alt=\"LDAP Account Manager\"></a></p><hr>\n<p>&nbsp;</p>\n");
@@ -204,12 +213,12 @@ echo "<tr><td><br><br>\n";
 if (sizeof($availableTypes) > 0) {
 	echo "<fieldset><legend><b>" . _("Available account types") . "</b></legend>\n";
 	echo "<table>\n";
-	for ($i = 0; $i < sizeof($availableTypes); $i++) {
-		$icon = '<img alt="' . $availableTypes[$i] . '" src="../../graphics/' . $availableTypes[$i] . '.png">&nbsp;';
+	foreach ($availableTypes as $key => $value) {
+		$icon = '<img alt="' . $value . '" src="../../graphics/' . $key . '.png">&nbsp;';
 		echo "<tr>\n";
-			echo "<td>$icon<b>" . getTypeAlias($availableTypes[$i]) . ": </b></td>\n";
-			echo "<td>" . getTypeDescription($availableTypes[$i]) . "</td>\n";
-			echo "<td><input type=\"submit\" name=\"add_" . $availableTypes[$i] ."\" title=\"" . _("Add") . "\" value=\" \"" .
+			echo "<td>$icon<b>" . $value . ": </b></td>\n";
+			echo "<td>" . getTypeDescription($key) . "</td>\n";
+			echo "<td><input type=\"submit\" name=\"add_" . $key ."\" title=\"" . _("Add") . "\" value=\" \"" .
 				" style=\"background-image: url(../../graphics/add.png);background-position: 2px center;background-repeat: no-repeat;width:24px;height:24px;background-color:transparent\"></td>\n";
 		echo "</tr>\n";
 	}
