@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: profmanage.php,v 1.33 2009/10/27 18:46:33 gruberroland Exp $
+$Id: profmanage.php,v 1.34 2010/01/01 17:39:38 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2009  Roland Gruber
@@ -62,7 +62,13 @@ echo $_SESSION['header'];
 		<hr><br>
 
 <?php
-echo "<script type=\"text/javascript\" src=\"../wz_tooltip.js\"></script>\n";
+// include all JavaScript files
+$jsDirName = dirname(__FILE__) . '/../lib';
+$jsDir = dir($jsDirName);
+while ($jsEntry = $jsDir->read()) {
+	if (substr($jsEntry, strlen($jsEntry) - 3, 3) != '.js') continue;
+	echo "<script type=\"text/javascript\" src=\"../lib/" . $jsEntry . "\"></script>\n";
+}
 
 $cfg = new LAMCfgMain();
 // check if submit button was pressed
