@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: initsuff.php,v 1.22 2009/11/24 15:19:38 gruberroland Exp $
+$Id: initsuff.php,v 1.24 2010/05/07 19:11:24 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2006  Roland Gruber
+  Copyright (C) 2003 - 2010  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -47,8 +47,8 @@ if (!checkIfWriteAccessIsAllowed()) {
 setlanguage();
 
 // check if user already pressed button
-if ($_POST['add_suff'] || $_POST['cancel']) {
-	if ($_POST['add_suff']) {
+if (isset($_POST['add_suff']) || isset($_POST['cancel'])) {
+	if (isset($_POST['add_suff'])) {
 		$fail = array();
 		$errors = array();
 		$new_suff = $_POST['new_suff'];
@@ -142,12 +142,9 @@ if ($_POST['add_suff'] || $_POST['cancel']) {
 			}
 		}
 	}
-	echo $_SESSION['header'];
-	echo "<title>initsuff</title>\n";
-	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../style/layout.css\">\n";
-	echo "</head>\n<body>\n";
+	include 'main_header.php';
 	// print error/success messages
-	if ($_POST['add_suff']) {
+	if (isset($_POST['add_suff'])) {
 		if (sizeof($fail) > 0) {
 			// print error messages
 			for ($i = 0; $i < sizeof($fail); $i++) {
@@ -175,10 +172,7 @@ $new_suff = str_replace("\\", "", $new_suff);
 $new_suff = str_replace("'", "", $new_suff);
 $new_suff = explode(";", $new_suff);
 
-echo $_SESSION['header'];
-echo "<title>initsuff</title>\n";
-echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../style/layout.css\">\n";
-echo "</head><body>\n";
+include 'main_header.php';
 	echo "<p>&nbsp;</p>\n";
 	echo "<p><font color=\"red\"><b>" . _("The following suffix(es) are missing in LDAP. LAM can create them for you.") . "</b></font></p>\n";
 	echo "<p>&nbsp;</p>\n";
