@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: deletelink.php,v 1.2 2009/10/27 18:46:33 gruberroland Exp $
+$Id: deletelink.php,v 1.3 2010/01/01 17:21:45 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2007  Roland Gruber
+  Copyright (C) 2007 - 2010  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -55,11 +55,8 @@ if (isset($dn) && isset($type)) {
 
 }
 else {
-	// print error message if user was not found
-	echo $_SESSION['header'];
-	echo "<title>userlink</title>\n";
-	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/layout.css\">\n";
-	echo "</head><body>\n";
+	// print error message if arguments are missing
+	include '../main_header.php';
 	StatusMessage("ERROR", "No account or type given.");
 	echo ("</body></html>\n");
 }
