@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: userlink.php,v 1.22 2009/10/28 16:36:08 gruberroland Exp $
+$Id: userlink.php,v 1.25 2010/02/06 11:52:48 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2006  Roland Gruber
+  Copyright (C) 2003 - 2010  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -52,15 +52,12 @@ $dn = search_username($user);
 
 if ($dn) {
 	// redirect to account/edit.php
-	metaRefresh("../account/edit.php?type=user&amp;DN='$dn'");
+	metaRefresh("../account/edit.php?type=user&amp;DN='" . rawurlencode($dn) . "'");
 
 }
 else {
 	// print error message if user was not found
-	echo $_SESSION['header'];
-	echo "<title>userlink</title>\n";
-	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/layout.css\">\n";
-	echo "</head><body>\n";
+	include '../main_header.php';
 	StatusMessage("ERROR", "", _("This user was not found!") . " (" . $user . ")");
 	echo "<p>&nbsp;</p>";
 	echo "<p><a href=\"list.php?type=group\">" . _("Back to group list") . "</a></p>";
@@ -75,15 +72,9 @@ else {
 * @return string DN
 */
 function search_username($name) {
-	$filter = "(uid=$name)";
-	$attrs = array();
-	$sr = @ldap_search($_SESSION['ldap']->server(), escapeDN($_SESSION['config']->get_Suffix('user')), $filter, $attrs, 0, 0, 0, LDAP_DEREF_NEVER);
-	if ($sr) {
-		$info = ldap_get_entries($_SESSION['ldap']->server(), $sr);
-		// return only first DN entry
-		$ret = $info[0]["dn"];
-		ldap_free_result($sr);
-		return $ret;
+	$entries = searchLDAPByAttribute('uid', $name, null, array('dn'), array('user'));
+	if (sizeof($entries) > 0 ) {
+		return $entries[0]['dn'];
 	}
 	else return "";
 }
