@@ -1,9 +1,10 @@
 <?php
 /*
-$Id: login.php,v 1.123 2009/11/03 20:57:53 gruberroland Exp $
+$Id: login.php,v 1.135 2010/05/28 13:45:34 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2006  Michael Duergner
+                2005 - 2010  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -25,110 +26,74 @@ $Id: login.php,v 1.123 2009/11/03 20:57:53 gruberroland Exp $
 * Login form of LDAP Account Manager.
 *
 * @author Michael Duergner
+* @author Roland Gruber
 * @package main
 */
 
 /** status messages */
 include_once("../lib/status.inc");
 
-// check if PHP >= 5.1
-if (version_compare(phpversion(), '5.1.0') < 0) {
-	echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n\n";
-	echo "<html>\n<head>\n";
-	echo "<meta http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\">\n";
-	echo "<meta http-equiv=\"pragma\" content=\"no-cache\">\n		<meta http-equiv=\"cache-control\" content=\"no-cache\">\n";
-	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../style/layout.css\">\n";
-	echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"../graphics/favicon.ico\">\n";
-	echo "<title>LDAP Account Manager</title>\n";
-	echo "</head><body>\n";
-	StatusMessage("ERROR", "LAM needs PHP 5 greater or equal as 5.1.0!", "Please upgrade your PHP installation.");
-	echo "<br><br>";
-	echo "</body></html>";
-	exit();
-}
-
+/** check environment */
+include '../lib/checkEnvironment.inc';
 
 /** security functions */
 include_once("../lib/security.inc");
 /** self service functions */
 include_once("../lib/selfService.inc");
-
-// check environment
-$criticalErrors = array();
-// check if PHP has session support
-if (! function_exists('session_start')) {
-	$criticalErrors[] = array("ERROR", "Your PHP has no session support!", "Please install the session extension for PHP.");
-}
-// check if PHP has LDAP support
-if (! function_exists('ldap_search')) {
-	$criticalErrors[] = array("ERROR", "Your PHP has no LDAP support!", "Please install the LDAP extension for PHP.");
-}
-// check if PHP has gettext support
-if (! function_exists('gettext') || !function_exists('_')) {
-	$criticalErrors[] = array("ERROR", "Your PHP has no gettext support!", "Please install gettext for PHP.");
-}
-// check if PHP has XML support
-if (! function_exists('utf8_decode')) {
-	$criticalErrors[] = array("ERROR", "Your PHP has no XML support!", "Please install the XML extension for PHP.");
-}
-// check file permissions
-$writableDirs = array('sess', 'tmp');
-for ($i = 0; $i < sizeof($writableDirs); $i++) {
-	$path = realpath('../') . "/" . $writableDirs[$i];
-	if (!is_writable($path)) {
-		$criticalErrors[] = array("ERROR", 'The directory %s is not writable for the web server. Please change your file permissions.', '', array($path));
-	}
-}
-// check session auto start
-if (ini_get("session.auto_start") == "1") {
-	$criticalErrors[] = array("ERROR", "Please deactivate session.auto_start in your php.ini. LAM will not work if it is activated.");
-}
-$memLimit = ini_get('memory_limit');
-if (isset($memLimit) && ($memLimit != '') && (substr(strtoupper($memLimit), strlen($memLimit) - 1) == 'M')) {
-	if (intval(substr($memLimit, 0, strlen($memLimit) - 1)) < 64) {
-		$criticalErrors[] = array("ERROR", "Please increase the \"memory_limit\" parameter in your php.ini to at least \"64M\".",
-			"Your current memory limit is $memLimit.");	
-	}
-}
-// stop login if critical errors occured
-if (sizeof($criticalErrors) > 0) {
-	echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n\n";
-	echo "<html>\n<head>\n";
-	echo "<meta http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\">\n";
-	echo "<meta http-equiv=\"pragma\" content=\"no-cache\">\n		<meta http-equiv=\"cache-control\" content=\"no-cache\">\n";
-	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../style/layout.css\">\n";
-	echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"../graphics/favicon.ico\">\n";
-	echo "<title>LDAP Account Manager</title>\n";
-	echo "</head><body>\n";
-	for ($i = 0; $i < sizeof($criticalErrors); $i++) {
-		call_user_func_array("StatusMessage", $criticalErrors[$i]);
-		echo "<br><br>";
-	}
-	echo "</body></html>";
-	exit();
-}
-
-
 /** access to configuration options */
 include_once("../lib/config.inc"); // Include config.inc which provides Config class
 
 // set session save path
 if (strtolower(session_module_name()) == 'files') {
-	session_save_path("../sess");
+	session_save_path(dirname(__FILE__) . '/../sess');
 }
-session_start(); // Start LDAP Account Manager session
+
+// start empty session and change ID for security reasons
+session_start();
+session_destroy();
+session_start();
+session_regenerate_id(true);
 
 // save last selected login profile
 if(isset($_POST['profile'])) {
 	setcookie("lam_default_profile", $_POST['profile'], time() + 365*60*60*24);
 }
 
+// init some session variables
+$default_Config = new LAMCfgMain();
+$_SESSION["cfgMain"] = $default_Config;
+$default_Profile = $default_Config->default;
+if(isset($_COOKIE["lam_default_profile"])) {
+	$default_Profile = $_COOKIE["lam_default_profile"];
+}
+// Reload loginpage after a profile change
+if(isset($_POST['profileChange'])) {
+	logNewMessage(LOG_DEBUG, "Change server profile to " . $_POST['profile']);
+	$_SESSION['config'] = new LAMConfig($_POST['profile']); // Recreate the config object with the submited
+}
+// Load login page
+else {
+	$_SESSION["config"] = new LAMConfig($default_Profile); // Create new Config object
+}
+
+$_SESSION['language'] = $_SESSION["config"]->get_defaultLanguage();
+if (isset($_POST['language'])) {
+	$_SESSION['language'] = $_POST['language']; // Write selected language in session
+}
+$current_language = explode(":",$_SESSION['language']);
+$_SESSION['header'] = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n\n";
+$_SESSION['header'] .= "<html>\n<head>\n";
+$_SESSION['header'] .= "<meta http-equiv=\"content-type\" content=\"text/html; charset=" . $current_language[1] . "\">\n";
+$_SESSION['header'] .= "<meta http-equiv=\"pragma\" content=\"no-cache\">\n		<meta http-equiv=\"cache-control\" content=\"no-cache\">";
+
+
 /**
 * Displays the login window.
 *
 * @param object $config_object current active configuration
 */
 function display_LoginPage($config_object) {
+	logNewMessage(LOG_DEBUG, "Display login page");
 	global $error_message;
 	// generate 256 bit key and initialization vector for user/passwd-encryption
 	// check if we can use /dev/random otherwise use /dev/urandom or rand()
@@ -147,15 +112,6 @@ function display_LoginPage($config_object) {
 		setcookie("Key", base64_encode($key), 0, "/");
 		setcookie("IV", base64_encode($iv), 0, "/");
 	}
-
-	$_SESSION['language'] = $config_object->get_defaultLanguage();
-
-	$current_language = explode(":",$_SESSION['language']);
-	$_SESSION['header'] = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n\n";
-	$_SESSION['header'] .= "<html>\n<head>\n";
-	$_SESSION['header'] .= "<meta http-equiv=\"content-type\" content=\"text/html; charset=" . $current_language[1] . "\">\n";
-	$_SESSION['header'] .= "<meta http-equiv=\"pragma\" content=\"no-cache\">\n		<meta http-equiv=\"cache-control\" content=\"no-cache\">";
-
 	// loading available languages from language.conf file
 	$languagefile = "../config/language";
 	if(is_file($languagefile) == True)
@@ -169,7 +125,7 @@ function display_LoginPage($config_object) {
 			$value = explode(":", $line);
 			$languages[$i]["link"] = $value[0] . ":" . $value[1];
 			$languages[$i]["descr"] = $value[2];
-			if(rtrim($line) == $_SESSION["language"])
+			if(trim($line) == trim($_SESSION["language"]))
 			{
 				$languages[$i]["default"] = "YES";
 			}
@@ -250,6 +206,20 @@ function display_LoginPage($config_object) {
 			StatusMessage("ERROR", _("Your session expired, please log in again."));
 			echo "<br>";
 		}
+		// check if main config was saved
+		if (isset($_GET['confMainSavedOk'])) {
+			StatusMessage("INFO", _("Your settings were successfully saved."));
+			echo "<br>";
+		}
+		// check if a server profile was saved
+		if (isset($_GET['configSaveOk'])) {
+			StatusMessage("INFO", _("Your settings were successfully saved."), htmlspecialchars($_GET['configSaveFile']));
+			echo "<br>";
+		}
+		elseif (isset($_GET['configSaveFailed'])) {
+			StatusMessage("ERROR", _("Cannot open config file!"), htmlspecialchars($_GET['configSaveFile']));
+			echo "<br>";
+		}
 		?>
 		<div style="position:relative; z-index:5;">
 		<table width="650" align="center" border="2" rules="none" bgcolor="white">
@@ -398,9 +368,11 @@ function display_LoginPage($config_object) {
 					<?php
 						if (isLAMProVersion()) {
 							echo "LDAP Account Manager <b>Pro</b>: <b>" . LAMVersion() . "</b>&nbsp;&nbsp;&nbsp;";
+							logNewMessage(LOG_DEBUG, "LAM Pro " . LAMVersion());
 						}
 						else {
 							echo "LDAP Account Manager: <b>" . LAMVersion() . "</b>&nbsp;&nbsp;&nbsp;";
+							logNewMessage(LOG_DEBUG, "LAM " . LAMVersion());
 						}
 					?>
 					</SMALL>
@@ -413,18 +385,21 @@ function display_LoginPage($config_object) {
 
 // checking if the submitted username/password is correct.
 if(!empty($_POST['checklogin'])) {
-	$_SESSION['lampath'] = realpath('../') . "/";  // Save full path to lam in session
-
 	include_once("../lib/ldap.inc"); // Include ldap.php which provides Ldap class
 
 	$_SESSION['ldap'] = new Ldap($_SESSION['config']); // Create new Ldap object
 
 	if($_POST['passwd'] == "") {
+		logNewMessage(LOG_DEBUG, "Empty password for login");
 		$error_message = _("Empty password submitted. Please try again.");
 		display_LoginPage($_SESSION['config']); // Empty password submitted. Return to login page.
+		exit();
 	}
 	else {
-		$clientSource = $_SERVER['REMOTE_ADDR'] . '/' . $_SERVER['REMOTE_HOST'];
+		$clientSource = $_SERVER['REMOTE_ADDR'];
+		if (isset($_SERVER['REMOTE_HOST'])) {
+			$clientSource .= '/' . $_SERVER['REMOTE_HOST'];
+		}
 		if (get_magic_quotes_gpc() == 1) {
 			$_POST['passwd'] = stripslashes($_POST['passwd']);
 		}
@@ -446,11 +421,12 @@ if(!empty($_POST['checklogin'])) {
 				if ($searchResult) {
 					$searchInfo = @ldap_get_entries($searchLDAP->server(), $searchResult);
 					if ($searchInfo) {
-						if ($searchInfo['count'] == 0) {
+						$searchInfo = cleanLDAPResult($searchInfo);
+						if (sizeof($searchInfo) == 0) {
 							$searchSuccess = false;
 							$searchError = _('Wrong password/user name combination. Please try again.');
 						}
-						elseif ($searchInfo['count'] > 1) {
+						elseif (sizeof($searchInfo) > 1) {
 							$searchSuccess = false;
 							$searchError = _('The given user name matches multiple LDAP entries.');
 						}
@@ -483,12 +459,6 @@ if(!empty($_POST['checklogin'])) {
 		$result = $_SESSION['ldap']->connect($username,$_POST['passwd']); // Connect to LDAP server for verifing username/password
 		if($result === 0) {// Username/password correct. Do some configuration and load main frame.
 			$_SESSION['loggedIn'] = true;
-			$_SESSION['language'] = $_POST['language']; // Write selected language in session
-			$current_language = explode(":",$_SESSION['language']);
-			$_SESSION['header'] = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">\n\n";
-			$_SESSION['header'] .= "<html>\n<head>\n";
-			$_SESSION['header'] .= "<meta http-equiv=\"content-type\" content=\"text/html; charset=" . $current_language[1] . "\">\n";
-			$_SESSION['header'] .= "<meta http-equiv=\"pragma\" content=\"no-cache\">\n		<meta http-equiv=\"cache-control\" content=\"no-cache\">";
 			// set security settings for session
 			$_SESSION['sec_session_id'] = session_id();
 			$_SESSION['sec_client_ip'] = $_SERVER['REMOTE_ADDR'];
@@ -504,48 +474,28 @@ if(!empty($_POST['checklogin'])) {
 				// connection failed
 				$error_message = _("Cannot connect to specified LDAP server. Please try again.");
 				logNewMessage(LOG_ERR, 'User ' . $_POST['username'] . ' (' . $clientSource . ') failed to log in (LDAP error: ' . ldap_err2str($result) . ').');
-				display_LoginPage($_SESSION['config']);
-				exit();
 			}
 			elseif ($result == 81) {
 				// connection failed
 				$error_message = _("Cannot connect to specified LDAP server. Please try again.");
 				logNewMessage(LOG_ERR, 'User ' . $_POST['username'] . ' (' . $clientSource . ') failed to log in (LDAP error: ' . ldap_err2str($result) . ').');
-				display_LoginPage($_SESSION['config']);
-				exit();
 			}
 			elseif ($result == 49) {
 				// user name/password invalid. Return to login page.
 				$error_message = _("Wrong password/user name combination. Please try again.");
 				logNewMessage(LOG_ERR, 'User ' . $_POST['username'] . ' (' . $clientSource . ') failed to log in (wrong password).');
-				display_LoginPage($_SESSION['config']);
-				exit();
 			}
 			else {
 				// other errors
 				$error_message = _("LDAP error, server says:") .  "\n<br>($result) " . ldap_err2str($result);
 				logNewMessage(LOG_ERR, 'User ' . $_POST['username'] . ' (' . $clientSource . ') failed to log in (LDAP error: ' . ldap_err2str($result) . ').');
-				display_LoginPage($_SESSION['config']);
-				exit();
 			}
+			display_LoginPage($_SESSION['config']);
+			exit();
 		}
 	}
 }
-// Reload loginpage after a profile change
-elseif(!empty($_POST['profileChange'])) {
-	$_SESSION['config'] = new LAMConfig($_POST['profile']); // Recreate the config object with the submited
-	display_LoginPage($_SESSION['config']); // Load login page
-}
-// Load login page
-else {
-	$default_Config = new LAMCfgMain();
-	$default_Profile = $default_Config->default;
-	if(isset($_COOKIE["lam_default_profile"])) {
-		$default_Profile = $_COOKIE["lam_default_profile"];
-	}
-	$_SESSION["config"] = new LAMConfig($default_Profile); // Create new Config object
-	$_SESSION["cfgMain"] = $default_Config; // Create new CfgMain object
 
-	display_LoginPage($_SESSION["config"]); // Load Login page
-}
+display_LoginPage($_SESSION["config"]);
+
 ?>
