@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: massDoUpload.php,v 1.14 2009/10/27 18:46:33 gruberroland Exp $
+$Id: massDoUpload.php,v 1.17 2010/02/16 17:32:48 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2004 - 2006  Roland Gruber
+  Copyright (C) 2004 - 2010  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -57,9 +57,7 @@ if (!isset($_SESSION['loggedIn']) || ($_SESSION['loggedIn'] !== true)) {
 // Set correct language, codepages, ....
 setlanguage();
 
-echo $_SESSION['header'];
-echo "<title>account upload</title>\n";
-echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../style/layout.css\">\n";
+include 'main_header.php';
 
 // create accounts
 $accounts = unserialize($_SESSION['ldap']->decrypt($_SESSION['mass_accounts']));
@@ -69,8 +67,6 @@ if (($_SESSION['mass_counter'] < sizeof($accounts)) || !isset($_SESSION['mass_po
 	if ($maxTime > 60) $maxTime = 60;
 	if ($maxTime <= 0) $maxTime = 60;
 	$refreshTime = $maxTime + 7;
-	echo "<meta http-equiv=\"refresh\" content=\"" . $refreshTime . "; URL=massDoUpload.php\">\n";
-	echo "</head>\n<body>\n";
 	echo "<h1>" . _("LDAP upload in progress. Please wait.") . "</h1>\n";
 	echo "<table align=\"center\" width=\"80%\" style=\"border-color: grey\" border=\"2\" cellspacing=\"0\" rules=\"none\">\n";
 	echo "<tr><td bgcolor=\"blue\" width=\"" . ($_SESSION['mass_counter'] * 100) / sizeof($accounts) . "%\">&nbsp;</td>";
@@ -98,7 +94,7 @@ if (($_SESSION['mass_counter'] < sizeof($accounts)) || !isset($_SESSION['mass_po
 	// do post upload actions
 	if ($_SESSION['mass_counter'] >= sizeof($accounts)) {
 		$data = unserialize($_SESSION['ldap']->decrypt($_SESSION['mass_data']));
-		$return  = doUploadPostActions($_SESSION['mass_scope'], $data, $_SESSION['mass_ids'], $_SESSION['mass_failed']);
+		$return  = doUploadPostActions($_SESSION['mass_scope'], $data, $_SESSION['mass_ids'], $_SESSION['mass_failed'], $_SESSION['mass_selectedModules']);
 		if ($return['status'] == 'finished') {
 			$_SESSION['mass_postActions']['finished'] = true;
 		}
@@ -110,13 +106,17 @@ if (($_SESSION['mass_counter'] < sizeof($accounts)) || !isset($_SESSION['mass_po
 		echo "</table>";
 		flush();
 		while (!isset($_SESSION['mass_postActions']['finished']) && (($startTime + $maxTime) > time())) {
-			$return  = doUploadPostActions($_SESSION['mass_scope'], $data, $_SESSION['mass_ids'], $_SESSION['mass_failed']);
+			$return  = doUploadPostActions($_SESSION['mass_scope'], $data, $_SESSION['mass_ids'], $_SESSION['mass_failed'], $_SESSION['mass_selectedModules']);
 			if ($return['status'] == 'finished') {
 				$_SESSION['mass_postActions']['finished'] = true;
 			}
 			for ($i = 0; $i < sizeof($return['errors']); $i++) $_SESSION['mass_errors'][] = $return['errors'][$i];
 		}
 	}
+	// refresh with JavaScript
+	echo "<script type=\"text/javascript\">\n";
+	echo "top.location.href = \"massDoUpload.php\";\n";
+	echo "</script>\n";
 	echo "</body></html>";
 }
 // all accounts have been created
