@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: ou_edit.php,v 1.29 2009/10/27 18:46:33 gruberroland Exp $
+$Id: ou_edit.php,v 1.33 2010/05/31 18:15:41 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2008  Roland Gruber
+  Copyright (C) 2003 - 2010  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -53,6 +53,9 @@ if (isset($_POST['abort'])) {
 	exit;
 }
 
+$error = null;
+$message = null;
+
 // check if submit button was pressed
 if (isset($_POST['createOU']) || isset($_POST['deleteOU'])) {
 	// new ou
@@ -97,9 +100,11 @@ if (isset($_POST['createOU']) || isset($_POST['deleteOU'])) {
 		$sr = @ldap_list($_SESSION['ldap']->server(), $_POST['deleteableOU'], "ObjectClass=*", array(""));
 		$info = @ldap_get_entries($_SESSION['ldap']->server(), $sr);
 		if ($sr && $info['count'] == 0) {
-			$text = "<br>\n" .
+			// print header
+			include 'main_header.php';
+			echo "<br>\n" .
 				"<p><big><b>" . _("Do you really want to delete this OU?") . " </b></big>" . "\n" .
-				"<br>\n<p>" . $_POST['deleteableOU'] . "</p>\n" .
+				"<br>\n<p>" . getAbstractDN($_POST['deleteableOU']) . "</p>\n" .
 				"<br>\n" .
 				"<form action=\"ou_edit.php\" method=\"post\">\n" .
 				"<input type=\"hidden\" name=\"deleteOU\" value=\"submit\">\n" .
@@ -107,60 +112,48 @@ if (isset($_POST['createOU']) || isset($_POST['deleteOU'])) {
 				"<input type=\"submit\" name=\"sure\" value=\"" . _("Delete") . "\">\n" .
 				"<input type=\"submit\" name=\"abort\" value=\"" . _("Cancel") . "\">\n" .
 				"</form>";
+			echo "</body></html>\n";
+			exit();
 		}
 		else {
 			$error = _("OU is not empty or invalid!");
 		}
 	}
-		
-	// print header
-	echo $_SESSION['header'];
-	echo ("<title>OU-Editor</title>\n");
-	echo ("<link rel=\"stylesheet\" type=\"text/css\" href=\"../style/layout.css\">\n");
-	echo ("</head>\n");
-	echo ("<body>\n");
-	// display messages
-	if ($error || $message || $text) {
-		if ($text) echo $text;
-		elseif ($error) {
-			StatusMessage("ERROR", "", $error);
-			echo ("<br><a href=\"ou_edit.php\">" . _("Back to OU-Editor") . "</a>\n");
-		}
-		else {
-			StatusMessage("INFO", "", $message);
-			echo ("<br><a href=\"ou_edit.php\">" . _("Back to OU-Editor") . "</a>\n");
-		}
-	}
-
-echo ("</body></html>\n");
-exit;
 }
 
-display_main();
+display_main($message, $error);
 
 /**
  * Displays the main page of the OU editor
+ * 
+ * @param String $message info message
+ * @param String $error error message
  */
-function display_main() {
-	$types = $_SESSION['config']->get_ActiveTypes();
+function display_main($message, $error) {
 	// display main page
-	echo $_SESSION['header'];
-	echo ("<title>OU-Editor</title>\n");
-	echo ("<link rel=\"stylesheet\" type=\"text/css\" href=\"../style/layout.css\">\n");
-	echo ("<link rel=\"stylesheet\" type=\"text/css\" href=\"../style/type_user.css\">\n");
-	echo ("</head>\n");
-	echo ("<body>\n");
-	echo "<script type=\"text/javascript\" src=\"wz_tooltip.js\"></script>\n";
+	include 'main_header.php';
 	echo "<h1>" . _("OU editor") . "</h1>";
+	if (isset($error)) {
+		StatusMessage("ERROR", "", $error);
+	}
+	elseif (isset($message)) {
+		StatusMessage("INFO", "", $message);
+	}
 	echo ("<br>\n");
 	echo ("<form action=\"ou_edit.php\" method=\"post\">\n");
 	
+	$types = array();
+	$typeList = $_SESSION['config']->get_ActiveTypes();
+	for ($i = 0; $i < sizeof($typeList); $i++) {
+		$types[$typeList[$i]] = getTypeAlias($typeList[$i]);
+	}
+	natcasesort($types);
 	$options = "";
-	for ($i = 0; $i < sizeof($types); $i++) {
-		$options .= "<optgroup label=\"" . getTypeAlias($types[$i]) . "\">\n";
-		$units = $_SESSION['ldap']->search_units($_SESSION["config"]->get_Suffix($types[$i]));
+	foreach ($types as $name => $title) {
+		$options .= "<optgroup label=\"" . $title . "\">\n";
+		$units = $_SESSION['ldap']->search_units($_SESSION["config"]->get_Suffix($name));
 		for ($u = 0; $u < sizeof($units); $u++) {
-			$options .= "<option>" . $units[$u] . "</option>\n";
+			$options .= "<option value=\"" . $units[$u] . "\">" . getAbstractDN($units[$u]) . "</option>\n";
 		}
 		$options .= "</optgroup>\n";
 	}
