@@ -1,10 +1,10 @@
 <?php
 /*
-$Id: pdfdelete.php,v 1.11 2009/10/27 18:46:33 gruberroland Exp $
+$Id: pdfdelete.php,v 1.13 2010/05/26 18:08:52 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2004 - 2006  Michael Duergner
-  Copyright (C) 2007         Roland Gruber
+                2007 - 2010  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@ $Id: pdfdelete.php,v 1.11 2009/10/27 18:46:33 gruberroland Exp $
 *
 * @package PDF
 * @author Michael Duergner
+* @author Roland Gruber
 */
 
 /** security functions */
@@ -48,35 +49,29 @@ if (!$_SESSION['ldap'] || !$_SESSION['ldap']->server()) {
 	exit;
 }
 
-// print standard header
-echo $_SESSION['header'];
-echo ("<title>" . _("Delete PDF structure") . "</title>\n");
-echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/layout.css\">\n";
-echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/type_" . $_POST['type'] . ".css\">\n";
-echo ("</head>\n<body>\n<p><br></p>\n");
-
 // check if admin has submited delete operation
 if ($_POST['submit']) {
 	// delete user profile
 	if(!deletePDFStructureDefinition($_POST['type'],$_POST['delete'])) {
-		StatusMessage('ERROR', '', _('Unable to delete PDF structure!') . ' ' . _('Scope') . ': ' . $_POST['type'] . ' ' . _('Name') . ': ' . $_POST['delete']);
+		metaRefresh('pdfmain.php?deleteScope=' . $_POST['type'] . '&amp;deleteFailed=' . $_POST['delete']);
+		exit();
 	}
 	else {
-		StatusMessage('INFO', '', _('Deleted PDF structure:') . ' ' . _('Scope') . ': ' . $_POST['type'] . ' ' . _('Name') . ': ' . $_POST['delete']);
+		metaRefresh('pdfmain.php?deleteScope=' . $_POST['type'] . '&amp;deleteSucceeded=' . $_POST['delete']);
+		exit();
 	}
-	echo ("<br><a href=\"pdfmain.php\">" . _("Back to PDF Editor") . "</a>");
-	echo ("</body></html>\n");
-	exit;
 }
 
 // check if admin has aborted delete operation
 if ($_POST['abort']) {
-	StatusMessage("INFO", "", _("Delete operation canceled."));
-	echo ("<br><a href=\"pdfmain.php\">" . _("Back to PDF Editor") . "</a>");
-	echo ("</body></html>\n");
+	metaRefresh('pdfmain.php');
 	exit;
 }
 
+// print standard header
+include '../main_header.php';
+echo ("<p><br></p>\n");
+
 // check if right type was given
 $type = $_GET['type'];
 echo ("<p align=\"center\"><big>" . _("Do you really want to delete this PDF structure?") . "</big>");
