@@ -1,10 +1,10 @@
 <?php
 /*
-$Id: pdfpage.php,v 1.35 2009/11/15 18:27:59 gruberroland Exp $
+$Id: pdfpage.php,v 1.40 2010/05/26 17:54:00 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   Copyright (C) 2003 - 2006  Michael Duergner
-  Copyright (C) 2007         Roland Gruber
+                2007 - 2010  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -84,28 +84,21 @@ if ((isset($_GET['headline'])) && ($_GET['headline'] != $_SESSION['currentPageDe
 
 // Check if pdfname is valid, then save current structure to file and go to
 // main pdf structure page
+$saveErrors = array();
 if(isset($_GET['submit'])) {
-	echo $_SESSION['header'];
-	echo "<title>LDAP Account Manager</title>";
-	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/layout.css\">\n";
-	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/type_" . $_GET['type'] . ".css\">\n";
-	echo "</head>";
-	echo "<body>";
 	if(!isset($_GET['pdfname']) || !preg_match('/[a-zA-Z0-9\-\_]+/',$_GET['pdfname'])) {
-		StatusMessage('ERROR', _('PDF-structure name not valid'), _('The name for that PDF-structure you submitted is not valid. A valid name must constist at least of one of the following characters \'a-z\',\'A-Z\',\'0-9\',\'_\',\'-\',\'.\'.'));
+		$saveErrors[] = array('ERROR', _('PDF structure name not valid'), _('The name for that PDF-structure you submitted is not valid. A valid name must consist of the following characters: \'a-z\',\'A-Z\',\'0-9\',\'_\',\'-\'.'));
 	}
 	else {
 		$return = savePDFStructureDefinitions($_GET['type'],$_GET['pdfname']);
 		if($return == 'ok') {
-			StatusMessage('INFO', _("PDF structure was successfully saved."), $_GET['pdfname']);
+			metaRefresh('pdfmain.php?savedSuccessfully=' . $_GET['pdfname']);
+			exit;
 		} 
 		elseif($return == 'no perms'){
-			StatusMessage('ERROR', _("Could not save PDF profile, access denied."), $_GET['pdfname']);
+			$saveErrors[] = array('ERROR', _("Could not save PDF structure, access denied."), $_GET['pdfname']);
 		}
 	}
-	echo ("<br><a href=\"pdfmain.php\">" . _("Back to PDF Editor") . "</a>");
-	echo "</body></html>";
-	exit;
 }
 // add a new text field
 elseif(isset($_GET['add_text'])) {
@@ -358,12 +351,30 @@ if(!isset($_SESSION['availablePDFFields'])) {
 $modules = array();
 $section_items_array = array();
 $section_items = '';
-foreach($_SESSION['availablePDFFields'] as $module => $values) {
-	$modules[] = $module;
-	foreach($values as $attribute) {
-		$section_items_array[] = $module . '_' . $attribute;
-		$section_items .= "<option>" . $module . '_' . $attribute . "</option>\n";
+$sortedModules = array();
+foreach($_SESSION['availablePDFFields'] as $module => $fields) {
+	if ($module != 'main') {
+		$title = getModuleAlias($module, $_GET['type']);
 	}
+	else {
+		$title = _('Main');
+	}
+	$sortedModules[$module] = $title;
+}
+natcasesort($sortedModules);
+foreach($sortedModules as $module => $title) {
+	$values = $_SESSION['availablePDFFields'][$module];
+	if (!is_array($values) || (sizeof($values) < 1)) {
+		continue;
+	}
+	$modules[] = $module;
+	$section_items .= "<optgroup label=\"" . $title . "\"\n>";
+	natcasesort($values);
+	foreach($values as $attribute => $attributeLabel) {
+		$section_items_array[] = $module . '_' . $attribute;
+		$section_items .= "<option value=\"" . $module . '_' . $attribute . "\">" . $attributeLabel . "</option>\n";
+	}
+	$section_items .= "</optgroup>\n";
 }
 $modules = join(',',$modules);
 
@@ -374,15 +385,17 @@ foreach($logoFiles as $logoFile) {
 }
 
 // print header
-echo $_SESSION['header'];
-// TODO Change enctype of form
+include '../main_header.php';
+
+// print error messages if any
+if (sizeof($saveErrors) > 0) {
+	for ($i = 0; $i < sizeof($saveErrors); $i++) {
+		call_user_func_array('StatusMessage', $saveErrors[$i]);
+	}
+	echo "<br>\n";
+}
+
 ?>
-		<title>LDAP Account Manager</title>
-		<link rel="stylesheet" type="text/css" href="../../style/layout.css">
-		<link rel="stylesheet" type="text/css" href="../../style/type_<?php echo $_GET['type']; ?>.css">
-	</head>
-	<body>
-	<script type="text/javascript" src="../wz_tooltip.js"></script>
 		<br>
 		<form action="pdfpage.php" method="post">
 			<table>
@@ -428,25 +441,26 @@ foreach($_SESSION['currentPDFStructure'] as $key => $entry) {
 	// We have a new section to start
 	if($entry['tag'] == "SECTION" && $entry['type'] == "open") {
 		$name = $entry['attributes']['NAME'];
-		if(preg_match("/^_[a-zA-Z_]+/",$name)) {
-			$section_headline = substr($name,1);
+		if(preg_match("/^_[a-zA-Z0-9_]+_[a-zA-Z0-9_]+/",$name)) {
+			$section_headline = translateFieldIDToName(substr($name,1), $_GET['type']);
 		}
 		else {
 			$section_headline = $name;
 		}
 		$nonTextSections .= '<option value="' . $key . '">' . $section_headline . "</option>\n";
+		$sections .= '<option value="' . ($key) . '">' . $section_headline . "</option>\n";
 		?>
 								<tr>
 									<td nowrap colspan="2">
 		<?php
 		// Section headline is a value entry
-		if(preg_match("/^_[a-zA-Z_]+/",$name)) {
+		if(preg_match("/^_[a-zA-Z0-9_]+_[a-zA-Z0-9_]+/",$name)) {
 			?>
 										<select name="section_<?php echo $key;?>">
 			<?php
 			foreach($section_items_array as $item) {
 				?>
-											<option value="_<?php echo $item;?>"<?php echo ((substr($name,1) == $item) ? ' selected' : '');?>><?php echo $item;?></option>
+											<option value="_<?php echo $item;?>"<?php echo ((substr($name,1) == $item) ? ' selected' : '');?>><?php echo translateFieldIDToName($item, $_GET['type']);?></option>
 				<?php
 			}
 			?>
@@ -469,15 +483,6 @@ foreach($_SESSION['currentPDFStructure'] as $key => $entry) {
 	}
 	// We have a section to end
 	elseif($entry['tag'] == "SECTION" && $entry['type'] == "close") {
-		if(preg_match("/^_[a-zA-Z_]+/",$name)) {
-			$section_headline = substr($name,1);
-		}
-		else {
-			$section_headline = $name;
-		}
-		// Add current section for dropdown box needed for the position when inserting a new
-		// section or static text entry
-		$sections .= '<option value="' . ($key + 1) . '">' . $section_headline . "</option>\n";
 		?>
 								<tr>
 									<td colspan="7">
@@ -528,7 +533,7 @@ foreach($_SESSION['currentPDFStructure'] as $key => $entry) {
 									<td width="20">
 									</td>
 									<td>
-										<?php echo $name;?>
+										<?php echo translateFieldIDToName($name, $_GET['type']);?>
 									</td>
 									<td width="20">
 									</td>
@@ -635,19 +640,14 @@ foreach($_SESSION['currentPDFStructure'] as $key => $entry) {
 								</legend><BR>
 								<select name="new_field">
 								<?php
-									foreach($_SESSION['availablePDFFields'] as $module => $fields) {
+									foreach($sortedModules as $module => $title) {
+										$fields = $_SESSION['availablePDFFields'][$module];
 										if (isset($fields) && is_array($fields) && (sizeof($fields) > 0)) {
-											sort($fields);
-											if ($module != 'main') {
-												$title = getModuleAlias($module, $_GET['type']);
-											}
-											else {
-												$title = _('Main');
-											}
+											natcasesort($fields);
 											echo "<optgroup label=\"$title\">\n";
-												foreach ($fields as $field) {
-													echo "<option value=\"" . $module . "_" . $field . "\" label=\"$field\">$field</option>\n";
-												}
+											foreach ($fields as $field => $fieldLabel) {
+												echo "<option value=\"" . $module . "_" . $field . "\" label=\"$fieldLabel\">$fieldLabel</option>\n";
+											}
 											echo "</optgroup>\n";
 										}
 									}
@@ -668,58 +668,60 @@ foreach($_SESSION['currentPDFStructure'] as $key => $entry) {
 							<legend>
 								<b><?php echo _("Save"); ?></b>
 							</legend><BR>
-							<table border="0" align="left">
-							<?php
-							if(!isset($_GET['pdfname']) || ($_GET['pdfname'] == '')) {
-							?>
-								<tr>
-									<td>
-										<b><?php echo _("Structure name"); ?>:</b>
-									</td>
-									<td>
-										<input type="text" name="pdfname" value="<?php if (isset($_GET['edit'])) echo $_GET['edit'];?>">
-									</td>
-									<td>
-									<?php
-										printHelpLink(getHelp('', '360'), '360');
-									?>
-									</td>
-								</tr>
-								<tr>
-									<td colspan="3">
-										&nbsp;
-									</td>
-								</tr>
-							<?php
-							}
-							?>
-								<tr>
-									<td>
-									<?php
-									if(isset($_GET['pdfname'])) {
-									?>
-										<input type="hidden" name="pdfname" value="<?php if (isset($_GET['pdfname'])) echo $_GET['pdfname']; ?>">
-									<?php
+								<b><?php echo _("Structure name"); ?>:</b>
+								<?php
+									$structureName = '';
+									if (isset($_GET['edit'])) {
+										$structureName = $_GET['edit'];
 									}
-									?>
-										<input type="submit" name="submit" value="<?php echo _("Save");?>">
-									</td>
-									<td>
-										<input type="submit" name="abort" value="<?php echo _("Cancel");?>">
-									</td>
-									<td>
-										&nbsp;
-									</td>
-								</tr>
-							</table>
+									else if (isset($_POST['pdfname'])) {
+										$structureName = $_POST['pdfname'];
+									}
+								?>
+								<input type="text" name="pdfname" value="<?php echo $structureName;?>">
+								<?php
+									printHelpLink(getHelp('', '360'), '360');
+								?>
+								<br><br>
+								<input type="submit" name="submit" value="<?php echo _("Save");?>">
+								&nbsp;
+								<input type="submit" name="abort" value="<?php echo _("Cancel");?>">
 						</fieldset>
 					</td>
 				</tr>
 			</table>
 		<input type="hidden" name="modules" value="<?php echo $modules;?>">
 		<input type="hidden" name="type" value="<?php echo $_GET['type'];?>">
+		<br><br><br>
 	</form>
 	</body>
 </html>
+
 <?php
-?>
\ No newline at end of file
+
+/**
+ * Translates a given field ID (e.g. inetOrgPerson_givenName) to its descriptive name.
+ *
+ * @param String $id field ID
+ * @param String $scope account type
+ */
+function translateFieldIDToName($id, $scope) {
+	foreach ($_SESSION['availablePDFFields'] as $module => $fields) {
+		if (!(strpos($id, $module . '_') === 0)) {
+			continue;
+		}
+		foreach ($fields as $name => $label) {
+			if ($id == $module . '_' . $name) {
+				if ($module == 'main') {
+					return _('Main') . ': ' . $label;
+				}
+				else  {
+					return getModuleAlias($module, $scope) . ': ' . $label;
+				}
+			}
+		}
+	}
+	return $id;
+}
+
+?>
