@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: profilepage.php,v 1.38 2009/10/27 18:46:33 gruberroland Exp $
+$Id: profilepage.php,v 1.42 2010/05/31 19:35:55 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2003 - 2009  Roland Gruber
+  Copyright (C) 2003 - 2010  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -66,12 +66,7 @@ if (isset($_POST['abort'])) {
 	exit;
 }
 
-// print header
-echo $_SESSION['header'];
-echo "<title>Profile editor</title>\n<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/layout.css\">\n";
-echo "\n<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/type_" . $_GET['type'] . ".css\">\n";
-echo "</head><body><br>\n";
-echo "<script type=\"text/javascript\" src=\"../wz_tooltip.js\"></script>\n";
+$errors = array();
 
 // save button was presed
 if (isset($_POST['save'])) {
@@ -108,30 +103,29 @@ if (isset($_POST['save'])) {
 	
 	// check options
 	$errors = checkProfileOptions($_POST['accounttype'], $options);
-	// print error messages if any
-	if (sizeof($errors) > 0) {
-		for ($i = 0; $i < sizeof($errors); $i++) {
-			if (sizeof($errors[$i]) > 3) {  // messages with additional variables
-				StatusMessage($errors[$i][0], $errors[$i][1], $errors[$i][2], $errors[$i][3]);
-			}
-			else {
-				StatusMessage($errors[$i][0], $errors[$i][1], $errors[$i][2]);
-			}
-		}
-		echo "<br>\n";
-	}
-	else {  // input data is valid, save profile
+	if (sizeof($errors) == 0) {  // input data is valid, save profile
 		// save profile
 		if (saveAccountProfile($options, $_POST['profname'], $_POST['accounttype'])) {
-			echo StatusMessage("INFO", _("Profile was saved."), $_POST['profname']);
-			echo ("<br><p><a href=\"profilemain.php\">" . _("Back to profile editor") . "</a></p>");
-			echo "</body></html>";
+			metaRefresh('profilemain.php?savedSuccessfully=' . $_POST['profname']);
 			exit();
 		}
-		else StatusMessage("ERROR", _("Unable to save profile!"), $_POST['profname']);
+		else {
+			$errors[] = array("ERROR", _("Unable to save profile!"), $_POST['profname']);
+		}
 	}
 }
 
+// print header
+include '../main_header.php';
+
+// print error messages if any
+if (sizeof($errors) > 0) {
+	for ($i = 0; $i < sizeof($errors); $i++) {
+		call_user_func_array('StatusMessage', $errors[$i]);
+	}
+	echo "<br>\n";
+}
+	
 // empty list of attribute types
 $_SESSION['profile_types'] = array();
 
@@ -187,10 +181,10 @@ echo "<legend><img align=\"middle\" src=\"../../graphics/logo32.png\" alt=\"logo
 	echo "<select name=\"ldap_suffix\" tabindex=\"1\">";
 	for ($i = 0; $i < sizeof($suffixes); $i++) {
 		if (isset($old_options['ldap_suffix']) && ($old_options['ldap_suffix'][0] == $suffixes[$i])) {
-			echo "<option selected>" . $suffixes[$i] . "</option>\n";
+			echo "<option selected value=\"" .$suffixes[$i] . "\">" . getAbstractDN($suffixes[$i]) . "</option>\n";
 		}
 		else {
-			echo "<option>" . $suffixes[$i] . "</option>\n";
+			echo "<option value=\"" .$suffixes[$i] . "\">" . getAbstractDN($suffixes[$i]) . "</option>\n";
 		}
 	}
 	echo "</select>\n";
@@ -250,7 +244,11 @@ for ($m = 0; $m < sizeof($modules); $m++) {
 // profile name and submit/abort buttons
 echo ("<b>" . _("Profile name") . ":</b> \n");
 $tabindex++;
-echo ("<input tabindex=\"$tabindex\" type=\"text\" name=\"profname\" value=\"" . $_GET['edit'] . "\">\n");
+$profName = '';
+if (isset($_GET['edit'])) {
+	$profName = $_GET['edit'];
+}
+echo ("<input tabindex=\"$tabindex\" type=\"text\" name=\"profname\" value=\"" . $profName . "\">\n");
 printHelpLink(getHelp('', '360'), '360');
 echo "<br><br>\n";
 $tabindex++;
