@@ -1,9 +1,9 @@
 <?php
 /*
-$Id: schemaTest.php,v 1.3 2009/10/27 18:46:33 gruberroland Exp $
+$Id: schemaTest.php,v 1.5 2010/05/31 18:10:36 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
-  Copyright (C) 2007  Roland Gruber
+  Copyright (C) 2007 - 2010  Roland Gruber
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -45,20 +45,9 @@ if (!checkIfWriteAccessIsAllowed()) die();
 
 setlanguage();
 
-echo $_SESSION['header'];
+include '../main_header.php';
 
-
-echo "<title></title>\n";
-echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/layout.css\">\n";
-$types = $_SESSION['config']->get_ActiveTypes();
-for ($t = 0; $t < sizeof($types); $t++) {
-	echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"../../style/type_" . $types[$t] . ".css\">\n";
-}
-echo "</head>";
-
-echo "<body>\n";
-
-echo "<h1 align=\"center\">" . _("Schema test") . "</h1>\n";
+echo "<h1>" . _("Schema test") . "</h1>\n";
 
 get_schema_objectclasses();
 $classes = get_cached_schema('objectclasses');
@@ -87,7 +76,7 @@ for ($t = 0; $t < sizeof($types); $t++) {
 		echo "<tr class=\"" . $types[$t] . "list\">\n";
 		echo "<td style=\"padding-left:10px;\" nowrap>" . getModuleAlias($modules[$m], $types[$t]) . "</td>\n";
 		// icon
-		echo "<td style=\"padding-left:10px;padding-right:10px;\"><img alt=\"\" src=\"" . $icon . "\"></td>\n";
+		echo "<td style=\"padding-left:10px;padding-right:10px;\"><img width=16 height=16 alt=\"\" src=\"" . $icon . "\"></td>\n";
 		// text
 		echo "<td width=\"100%\">" . $message . "</td>\n";
 		echo "</tr>\n";
