@@ -1,6 +1,6 @@
 <?php
 /*
-$Id: edit.php,v 1.9 2009/10/27 18:46:33 gruberroland Exp $
+$Id: edit.php,v 1.11 2010/05/07 19:13:54 gruberroland Exp $
 
   This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
   
@@ -94,11 +94,8 @@ echo "</head>\n";
 <table class="tree_edit_dn_menu">
 
 <tr>
-	<?php  $time = gettimeofday(); $random_junk = md5( strtotime( 'now' ) . $time['usec'] ); ?>
 	<td class="icon"><img src="../../graphics/refresh.png" /></td>
-	<td><a href="edit.php?dn=<?php echo $encoded_dn; ?>&amp;random=<?php
-			echo $random_junk; ?>"
-	       title="<?php echo _('Refresh'); ?>"><?php echo _('Refresh'); ?></a></td>
+	<td><a href="edit.php?dn=<?php echo $encoded_dn; ?>" title="<?php echo _('Refresh'); ?>"><?php echo _('Refresh'); ?></a></td>
 <?php if( $show_internal_attrs ) { ?>
     <td class="icon"><img src="../../graphics/tools-no.png" /></td>
     <td><a href="edit.php?dn=<?php echo $encoded_dn; ?>"><?php echo _('Hide internal attributes'); ?></a></td>
@@ -167,7 +164,10 @@ if( $show_internal_attrs ) {
 		?>
 
         <tr>
-		<td class="val">
+        <td class="attr">
+        	<b><?php echo htmlspecialchars($attr); ?></b>
+        </td>
+		<td>
         <?php 
            if( is_attr_binary( $attr ) ) {
                $href = "download_binary_attr.php?dn=$encoded_dn&amp;attr=$attr";
